@@ -950,8 +950,7 @@ bool KisDocument::prepareLocksForSaving()
         Private::SafeSavingLocker locker(d);
         if (locker.successfullyLocked()) {
             copiedImage = d->image->clone(true);
-        }
-        else {
+        } else if (!isAutosaving()) {
             // even though it is a recovery operation, we should ensure we do not enter saving twice!
             std::unique_lock<StdLockableWrapper<QMutex>> l(d->savingLock, std::try_to_lock);
 
@@ -959,6 +958,7 @@ bool KisDocument::prepareLocksForSaving()
                 d->lastErrorMessage = i18n("The image was still busy while saving. Your saved image might be incomplete.");
                 d->image->lock();
                 copiedImage = d->image->clone(true);
+                copiedImage->initialRefreshGraph();
                 d->image->unlock();
             }
         }
