@@ -203,7 +203,7 @@ public:
     KisAction *saveActionAs {0};
 //    KisAction *printAction;
 //    KisAction *printActionPreview;
-    KisAction *exportPdf {0};
+//    KisAction *exportPdf {0};
     KisAction *importAnimation {0};
     KisAction *closeAll {0};
 //    KisAction *reloadFile;
@@ -963,7 +963,7 @@ bool KisMainWindow::saveDocument(KisDocument *document, bool saveas, bool silent
         // don't want to be reminded about overwriting files etc.
         bool justChangingFilterOptions = false;
 
-        KoFileDialog dialog(this, KoFileDialog::SaveFile, "OpenDocument");
+        KoFileDialog dialog(this, KoFileDialog::SaveFile, "SaveAs");
         dialog.setCaption(i18n("untitled"));
         if (isExporting() && !d->lastExportUrl.isEmpty()) {
             dialog.setDefaultDir(d->lastExportUrl.toLocalFile());
@@ -2292,11 +2292,10 @@ void KisMainWindow::createActions()
     d->redo = actionManager->createStandardAction(KStandardAction::Redo, this, SLOT(redo()));
     d->redo->setActivationFlags(KisAction::ACTIVE_IMAGE);
 
-    d->exportPdf  = actionManager->createAction("file_export_pdf");
-    connect(d->exportPdf, SIGNAL(triggered()), this, SLOT(exportToPdf()));
+//    d->exportPdf  = actionManager->createAction("file_export_pdf");
+//    connect(d->exportPdf, SIGNAL(triggered()), this, SLOT(exportToPdf()));
 
     d->importAnimation  = actionManager->createAction("file_import_animation");
-    d->importAnimation->setActivationFlags(KisAction::IMAGE_HAS_ANIMATION);
     connect(d->importAnimation, SIGNAL(triggered()), this, SLOT(importAnimation()));
 
     d->closeAll = actionManager->createAction("file_close_all");
@@ -2372,6 +2371,14 @@ void KisMainWindow::applyToolBarLayout()
         if (isPlastiqueStyle) {
             toolBar->setContentsMargins(0, 0, 0, 2);
         }
+        //Hide text for buttons with an icon in the toolbar
+        Q_FOREACH (QAction *ac, toolBar->actions()){
+            if (ac->icon().pixmap(QSize(1,1)).isNull() == false){
+                ac->setPriority(QAction::LowPriority);
+            }else {
+                ac->setIcon(QIcon());
+            }
+        }
     }
 }
 
