@@ -446,8 +446,27 @@ void LutDockerDock::selectOcioConfiguration()
 
 void LutDockerDock::resetOcioConfiguration()
 {
-    m_ocioConfig.reset();
     KisConfig cfg;
+    if (cfg.ocioColorManagementMode() == m_colorManagement->currentIndex()
+            && cfg.useOcio() == m_chkUseOcio->isChecked()
+            && cfg.ocioLockColorVisualRepresentation() == m_btnConvertCurrentColor->isChecked()
+            && cfg.ocioConfigurationPath() == m_txtConfigurationPath->text()
+            ) {
+        return;
+    }
+
+    m_ocioConfig.reset();
+
+    if (cfg.ocioColorManagementMode() == m_colorManagement->currentIndex()
+            && cfg.useOcio() == m_chkUseOcio->isChecked()
+            && cfg.ocioLockColorVisualRepresentation() == m_btnConvertCurrentColor->isChecked()
+            && cfg.ocioConfigurationPath() == m_txtConfigurationPath->text()
+            ) {
+        return;
+    }
+
+    m_ocioConfig.reset();
+
     try {
         if (cfg.ocioColorManagementMode() == KisConfig::INTERNAL) {
             m_ocioConfig = defaultRawProfile();
