@@ -34,11 +34,13 @@ public:
     KisSketchPaintOpSettings();
     virtual ~KisSketchPaintOpSettings() {}
 
-    QPainterPath brushOutline(const KisPaintInformation &info, OutlineMode mode) const;
+    QPainterPath brushOutline(const KisPaintInformation &info, OutlineMode mode);
 
     bool paintIncremental();
     bool isAirbrushing() const;
     int rate() const;
 };
 
+typedef KisSharedPtr<KisSketchPaintOpSettings> KisSketchPaintOpSettingsSP;
+
 #endif
